nxp-pac

Crates

git

Versions

mcxa256

Flavors

Ctrl2

Struct Ctrl2 

#[repr(transparent)]
pub struct Ctrl2(pub u16);
Control 2 Register

Tuple Fields

0: u16

Implementations

Source

impl Ctrl2

pub const fn updhld(&self) -> bool

Update Hold Registers

pub const fn set_updhld(&mut self, val: bool)

Update Hold Registers

pub const fn updpos(&self) -> bool

Update Position Registers

pub const fn set_updpos(&mut self, val: bool)

Update Position Registers

pub const fn opmode(&self) -> Opmode

Operation Mode Select

pub const fn set_opmode(&mut self, val: Opmode)

Operation Mode Select

pub const fn ldmod(&self) -> Ldmod

Buffered Register Load (Update) Mode Select

pub const fn set_ldmod(&mut self, val: Ldmod)

Buffered Register Load (Update) Mode Select

pub const fn revmod(&self) -> Revmod

Revolution Counter Modulus Enable

pub const fn set_revmod(&mut self, val: Revmod)

Revolution Counter Modulus Enable

pub const fn outctl(&self) -> Outctl

Output Control

pub const fn set_outctl(&mut self, val: Outctl)

Output Control

pub const fn pmen(&self) -> Pmen

Period measurement function enable

pub const fn set_pmen(&mut self, val: Pmen)

Period measurement function enable

pub const fn emip(&self) -> Emip

Enables/disables the position counter to be initialized by Index Event Edge Mark

pub const fn set_emip(&mut self, val: Emip)

Enables/disables the position counter to be initialized by Index Event Edge Mark

pub const fn initpos(&self) -> Initpos

Initial Position Register

pub const fn set_initpos(&mut self, val: Initpos)

Initial Position Register

pub const fn once(&self) -> Once

Count Once

pub const fn set_once(&mut self, val: Once)

Count Once

pub const fn cmode(&self) -> u8

Counting Mode

pub const fn set_cmode(&mut self, val: u8)

Counting Mode